@@ -15,6 +15,24 @@ instance Show Result where
 
 type Criterion = TRS -> IO Result
 
+succedTheoremYES :: Criterion
+succedTheoremYES trs = return (YES proof)
+  where
+    proof = "always YES:\n" ++ showTRS trs
+
+succedTheoremNO :: Criterion
+succedTheoremNO trs = return (NO proof)
+  where
+    proof = "always NO:\n" ++ showTRS trs
+
+failTheorem :: Criterion
+failTheorem _ = return MAYBE
+
+mapResult :: (String -> String) -> Result -> Result
+mapResult f (YES s) = YES (f s)
+mapResult f (NO s)  = NO (f s)
+mapResult _ MAYBE   = MAYBE
+
 isYES, isNO :: Result -> Bool
 isYES (YES _) = True
 isYES _       = False
@@ -39,6 +57,17 @@ lookupResult rs
   | Just x <- lookupNO rs  = Just x
   | otherwise              = Nothing
 
+anyYES, anyNO :: (a -> Result) -> [a] -> Bool
+anyYES f xs =
+  case lookupYES (map f xs) of
+    Just _ -> True
+    Nothing -> False
+
+anyNO f xs =
+  case lookupNO (map f xs) of
+    Just _ -> True
+    Nothing -> False
+
 -- find first non-MAYBE result from criteria
 oneOf :: [Criterion] -> Criterion
 oneOf [] _ = return MAYBE
